@@ -1,13 +1,13 @@
 """pavlovadm packaging information"""
 name = 'pavlovadm'
 provides = ['pavloavadm']
-version = '1.20'
+version = '1.23'
 install_requires = [
     'requests', 'inquirer', 'PyYAML']
 url = 'https://pypi.org/project/pavlovadm/'
 license = "GPLv3+"
 author = 'd0n'
-description = 'utility to issue commands to pavlov\'s rcon like admin interface'
+description = "utility to issue commands to pavlov's rcon like admin interface"
 author_email = 'd0n@janeiskla.de'
 classifiers = ['Environment :: Console',
                'Environment :: MacOS X',
@@ -28,7 +28,7 @@ classifiers = ['Environment :: Console',
                'Topic :: Desktop Environment']
 
 include_package_data = True
-long_description = 'utility to manage pavlov\'s rcon like admin interface'
+long_description = "utility to manage pavlov's rcon like admin interface"
 
 entry_points = {
     'console_scripts': ['pavlovadm = pavlovadm.__init__:pavlovadm']}
